@@ -10,9 +10,9 @@ from __future__ import absolute_import
 import sys
 import logging
 import argparse
-import dateutil.parser
 import datetime
 
+import dateutil.parser
 import pandas as pd
 
 import ecl2df
@@ -419,7 +419,7 @@ def main():
     pillarstats_main(parser.parse_args())
 
 
-def pillarstats_main(args):
+def pillars_main(args):
     """This is the command line API"""
     if args.verbose:
         logger.setLevel(logging.INFO)
